@@ -107,14 +107,11 @@ class FacebookResponse(object):
         """
         if self.is_failure():
             return FacebookRequestError(
-                "Call was not successful.\n" +
-                "Request:\n\t%s\n" % self._call +
-                "Response given:\n" +
-                "\tHTTP Status: %s\n\tHeaders: %s\n\tBody: %s\n" % (
-                    self.status(),
-                    self.headers(),
-                    self.body(),
-                )
+                "Call was not successful",
+                self._call,
+                self.status(),
+                self.headers(),
+                self.body()
             )
         else:
             return None
@@ -133,7 +130,7 @@ class FacebookAdsApi(object):
             this sdk.
     """
 
-    SDK_VERSION = '2.2.1'
+    SDK_VERSION = '2.2.2'
 
     API_VERSION = 'v2.2'
 
