@@ -26,6 +26,7 @@ Ads API.
 from facebookads.exceptions import FacebookBadObjectError
 from facebookads.api import FacebookAdsApi
 from facebookads.mixins import (
+    CanArchive,
     CannotCreate,
     CannotDelete,
     CannotUpdate,
@@ -117,8 +118,12 @@ class EdgeIterator(object):
 
         return self._queue.pop(0)
 
+    # Python 2 compatibility.
     next = __next__
 
+    def __getitem__(self, index):
+        return self._queue[index]
+
     def total(self):
         return self._total_count
 
@@ -265,7 +270,6 @@ class AbstractObject(collections.MutableMapping):
         return self.export_value(self._data)
 
 
-
 class AbstractCrudObject(AbstractObject):
     """
     Extends AbstractObject and implements methods to create, read, update,
@@ -294,9 +298,10 @@ class AbstractCrudObject(AbstractObject):
         self._changes = {}
 
         if fbid is not None:
-            self[self.__class__.Field.id] = fbid
+            self[self.__class__.Field.id] = str(fbid)
 
-        self.parent_id = parent_id
+        if parent_id is not None:
+            self.parent_id = str(parent_id)
         self.api = api
 
     def __setitem__(self, key, value):
@@ -309,6 +314,10 @@ class AbstractCrudObject(AbstractObject):
 
         return self
 
+    def __delitem__(self, key):
+        del self._data[key]
+        del self._changes[key]
+
     def __eq__(self, other):
         """Two objects are the same if they have the same fbid."""
         return (
@@ -615,6 +624,7 @@ class AbstractCrudObject(AbstractObject):
         """
         params = {} if params is None else params.copy()
         params.update(self.export_data())
+        self._set_data(params)
 
         if batch is not None:
             def callback_success(response):
@@ -745,42 +755,6 @@ class AbstractCrudObject(AbstractObject):
         return None
 
 
-class CannotCreate(object):
-
-    """
-    An instance of CannotCreate will raise a TypeError when calling
-    remote_create().
-    """
-
-    @classmethod
-    def remote_create(cls, *args, **kwargs):
-        raise TypeError('Cannot create object of type %s.' % cls.__name__)
-
-
-class CannotDelete(object):
-
-    """
-    An instance of CannotDelete will raise a TypeError when calling
-    remote_delete().
-    """
-
-    @classmethod
-    def remote_delete(cls, *args, **kwargs):
-        raise TypeError('Cannot delete object of type %s.' % cls.__name__)
-
-
-class CannotUpdate(object):
-
-    """
-    An instance of CannotUpdate will raise a TypeError when calling
-    remote_update().
-    """
-
-    @classmethod
-    def remote_update(cls, *args, **kwargs):
-        raise TypeError('Cannot update object of type %s.' % cls.__name__)
-
-
 class AdUser(CannotCreate, CannotDelete, CannotUpdate, AbstractCrudObject):
 
     """
@@ -821,7 +795,13 @@ class AdUser(CannotCreate, CannotDelete, CannotUpdate, AbstractCrudObject):
 
 class Activity(AbstractObject):
 
-    pass
+    class Field(object):
+        event_time = 'event_time'
+        event_type = 'event_type'
+
+    @classmethod
+    def get_endpoint(cls):
+        return 'activities'
 
 
 class AdAccount(CannotCreate, CannotDelete, AbstractCrudObject):
@@ -1120,42 +1100,7 @@ class AdAccountGroupUser(AbstractCrudObject):
         return AdUser(fbid=self[self.__class__.Field.uid])
 
 
-class HasObjective(object):
-
-    """
-    An instance of HasObjective will have an enum attribute Objective.
-    """
-
-    class Objective(object):
-        canvas_app_engagement = 'CANVAS_APP_ENGAGEMENT'
-        canvas_app_installs = 'CANVAS_APP_INSTALLS'
-        event_responses = 'EVENT_RESPONSES'
-        local_awareness = 'LOCAL_AWARENESS'
-        mobile_app_engagement = 'MOBILE_APP_ENGAGEMENT'
-        mobile_app_installs = 'MOBILE_APP_INSTALLS'
-        none = 'NONE'
-        offer_claims = 'OFFER_CLAIMS'
-        page_likes = 'PAGE_LIKES'
-        post_engagement = 'POST_ENGAGEMENT'
-        website_clicks = 'WEBSITE_CLICKS'
-        website_conversions = 'WEBSITE_CONVERSIONS'
-        video_views = 'VIDEO_VIEWS'
-
-
-class HasStatus(object):
-
-    """
-    An instance of HasStatus will have an enum attribute Status.
-    """
-
-    class Status(object):
-        active = 'ACTIVE'
-        archived = 'ARCHIVED'
-        deleted = 'DELETED'
-        paused = 'PAUSED'
-
-
-class AdCampaign(HasStatus, HasObjective, AbstractCrudObject):
+class AdCampaign(HasStatus, HasObjective, CanArchive, AbstractCrudObject):
 
     class Field(object):
         account_id = 'account_id'
@@ -1188,21 +1133,7 @@ class AdCampaign(HasStatus, HasObjective, AbstractCrudObject):
         return self.iterate_edge(AdStats, fields, params)
 
 
-class HasBidInfo(object):
-
-    """
-    An instance of HasBidInfo will have an enum attribute BidInfo.
-    """
-
-    class BidInfo(object):
-        actions = 'ACTIONS'
-        clicks = 'CLICKS'
-        impressions = 'IMPRESSIONS'
-        reach = 'REACH'
-        social = 'SOCIAL'
-
-
-class AdSet(HasStatus, AbstractCrudObject):
+class AdSet(HasStatus, CanArchive, AbstractCrudObject):
 
     class Field(HasBidInfo, object):
         account_id = 'account_id'
@@ -1251,7 +1182,7 @@ class AdSet(HasStatus, AbstractCrudObject):
         return self.iterate_edge(AdStats, fields, params)
 
 
-class AdGroup(HasStatus, HasObjective, AbstractCrudObject):
+class AdGroup(HasStatus, HasObjective, CanArchive, AbstractCrudObject):
 
     class Field(HasBidInfo, object):
         account_id = 'account_id'
@@ -1556,23 +1487,25 @@ class ClickTrackingTag(AbstractCrudObject):
 class CustomAudience(AbstractCrudObject):
 
     class Field(object):
-        description = 'description'
-        id = 'id'
-        name = 'name'
-        opt_out_link = 'opt_out_link'
-
         account_id = 'account_id'
         approximate_count = 'approximate_count'
         data_source = 'data_source'
         delivery_status = 'delivery_status'
+        description = 'description'
+        force_delete_lookalikes = 'force_delete_lookalikes'
+        id = 'id'
         lookalike_audience_ids = 'lookalike_audience_ids'
-        permission_for_actions = 'permission_for_actions'
+        lookalike_spec = 'lookalike_spec'
+        name = 'name'
         operation_status = 'operation_status'
+        opt_out_link = 'opt_out_link'
+        permission_for_actions = 'permission_for_actions'
+        prefill = 'prefill'
+        retention_days = 'retention_days'
+        rule = 'rule'
         subtype = 'subtype'
         time_updated = 'time_updated'
 
-        force_delete_lookalikes = 'force_delete_lookalikes'
-
     class Schema(object):
         uid = 'UID'
         email_hash = 'EMAIL_SHA256'
@@ -1845,8 +1778,8 @@ class ReachFrequencyPrediction(AbstractCrudObject):
 
     def cancel(self):
         params = {
-            self.__class__.Field.prediction_id: self.get_id_assured(),
-            self.__class__.Field.action: self.__class__.Action.cancel,
+            self.Field.prediction_id: self.get_id_assured(),
+            self.Field.action: self.__class__.Action.cancel,
         }
         self.get_api_assured().call(
             FacebookAdsApi.HTTP_METHOD_POST,
